use lazy_static::lazy_static;
use log::{debug, error, info};
use regex::Regex;
use serde::Deserialize;

use crate::default_false;
use crate::Action;
use crate::Client;
use crate::FormData;

#[derive(Debug, Deserialize)]
pub struct WotLog {
	/// ID of the log
	#[serde(default = "String::new")]
	pub id: String,

	/// Title of the log
	#[serde(default = "String::new")]
	pub title: String,

	/// Name of the player
	#[serde(default = "String::new")]
	pub player: String,

	/// Is the log public
	#[serde(default = "default_false")]
	pub public: bool,

	/// Log
	#[serde(default = "String::new")]
	pub log: String,

	/// Client type
	#[serde(default = "Client::default")]
	pub client: Client,
}

impl From<&FormData> for WotLog {
	fn from(form_data: &FormData) -> Self {
		Self {
			id: "".into(),
			title: form_data.title.clone(),
			player: form_data.player.clone(),
			public: if form_data.public == "public" { true } else { false },
			log: form_data.log.clone(),
			client: Client::None,
		}
	}
}

impl WotLog {
	/// Read and parse the log
	pub fn parse(self: &Self) {
		let mut lineno: u128 = 1;
		for line in self.log.lines() {
			let line = line.trim_end_matches('\r');

			let action = Action::from(line);
			lineno += 1;
		}
	}
}
